@@ -3,7 +3,9 @@ from .user import User
 from .message import Message
 from .. import utils
 from ..embed import Embed
+import pprint
 
+p = pprint.PrettyPrinter()
 
 class Context:
     def __init__(self, socket, data):
@@ -13,6 +15,7 @@ class Context:
 
         self.socket = socket
         self.raw = data
+        p.pprint(self.raw)
         self.resolved = self.raw['data'].get('resolved', None)
         self.command = self.raw['data'].get('name', None)
         self.command_id = self.raw['data'].get('id', None)
@@ -20,6 +23,7 @@ class Context:
         self.id = self.raw.get('id', None)
         self.token = self.raw.get('token', None)
         self.type = self.raw.get('type', None)
+        self.invoker = User(self.raw['member']['user'])
         self.callback_url = f"https://discord.com/api/v8/interactions/{self.id}/{self.token}/callback"
 
     async def callback(self, content: str = '', embeds: list = [], components: list = [], mentions: list = [], ephemeral: bool= False, type: int = utils.CHANNEL_WITH_SOURCE):
@@ -39,7 +43,7 @@ class Context:
             for action_row in components:
                 if isinstance(action_row, ActionRow):
                     built_action_rows.append(action_row.build())
-        
+
             fully_built = []
             for bar in built_action_rows:
                 new_ar = {"type": 1, "components": []}
@@ -63,10 +67,11 @@ class SelectMenuContext:
     def __init__(self, socket, data):
         self.socket = socket
         self.raw = data
+        p.pprint(self.raw)
         self.ucid = self.raw['data']['custom_id']
         self.values = self.raw['data']['values']
         self.used = User(self.raw['member']['user'])
-        self.invoked = User(data['message']['interaction']['user'])
+        self.invoker = User(data['message']['interaction']['user'])
         self.callback_url = f"https://discord.com/api/v8/interactions/{self.raw['id']}/{self.raw['token']}/callback"
 
     async def callback(self, content: str = '', embeds: list = [], components: list = [], mentions: list = [], ephemeral: bool= False, type: int = utils.CHANNEL_WITH_SOURCE):
@@ -86,7 +91,7 @@ class SelectMenuContext:
             for action_row in components:
                 if isinstance(action_row, ActionRow):
                     built_action_rows.append(action_row.build())
-        
+
             fully_built = []
             for bar in built_action_rows:
                 new_ar = {"type": 1, "components": []}
@@ -115,8 +120,9 @@ class ButtonContext:
     def __init__(self, socket, data):
         self.socket = socket
         self.raw = data
+        p.pprint(self.raw)
         self.ucid = self.raw['data']['custom_id']
-        self.invoked = User(data['message']['interaction']['user'])
+        self.invoker = User(data['message']['interaction']['user'])
         self.used = User(data['member']['user'])
         self.callback_url = f"https://discord.com/api/v8/interactions/{self.raw['id']}/{self.raw['token']}/callback"
 
@@ -137,7 +143,7 @@ class ButtonContext:
             for action_row in components:
                 if isinstance(action_row, ActionRow):
                     built_action_rows.append(action_row.build())
-        
+
             fully_built = []
             for bar in built_action_rows:
                 new_ar = {"type": 1, "components": []}
